@@ -2,7 +2,7 @@ package Math::Random::OO;
 use 5.006;
 use strict;
 use warnings;
-our $VERSION = "0.19";
+our $VERSION = '0.21';
 
 # Required modules
 use Carp;
@@ -26,7 +26,7 @@ numbers
   use Math::Random::OO::Normal;
   push @prngs, Math::Random::OO::Normal->new(0,2);
  
-  $_->seed(0.23) for (@prngs);
+  $_->seed(23) for (@prngs);
   print( $_->next(), "\n") for (@prngs);
 
 =head1 DESCRIPTION
@@ -146,6 +146,9 @@ of the random number generator.  As some subclasses may optionally use/require
 a list of seeds, the interface mandates that a list must be acceptable.
 Generators requiring a single seed must use the first value in the list.
 
+As seeds may be passed to the built-in C<srand()> function, they may be 
+truncated as integers, so 0.12 and 0.34 would be the same seed.
+
 =cut
 
 sub seed { die "call to abstract method 'seed'" }
